
#import <gamekit/gamekit.h>
#import "PacManGameBrain.h"
#import "PacManView.h"
#import "Player.h"
#import "PacManPreferencesBrain.h"
#import "FruitView.h"
#import <stdio.h>
#import <string.h>

@implementation PacManGameBrain

- (GKTrackerId)ghostId { return ghostId; }

- nextLevel		// move to next level-- called to start game
{
    [super nextLevel];
	[fruitBasket showLevel:level];
    return self;
}

- makeGameInfo
{
	id info = [super makeGameInfo];
	
	// Set up for the sound in our game; 2 types with 3 sounds each.
	// 2 streams is enough to overlap the sounds a little without them
	// getting too delayed.
	[[[info setnumSoundTypes:1] setnumSoundStreams:2] setnumSounds:4];
	[info setNumOneUps:4];
	
	return info;
}

- appDidInit:sender		// after init, but before 1st event.
{	// set up bonus trackers for eating ghosts and getting extra men
	id ghostTracker = [[BonusTracker alloc] init];
	id xtraManTracker = [[BonusTracker alloc] init];
	NXRect pacFrame = {{PAC_WIDTH * 2, PAC_WIDTH}, {PAC_WIDTH, PAC_WIDTH}};
	[xtraManTracker setBaseValue:10000];	// first xtra man at 10,000 pts.
	[xtraManTracker setBaseValue:15000];	// next xtra every 15,000 pts...
	[ghostTracker setBaseValue:200];	// first ghost is worth 200 pts.
	[ghostTracker setMultiplier:2];		// each ghost is worth 2x previous
	[super appDidInit:sender];
	ghostId = [scoreKeeper addBonusTracker:ghostTracker];
	[oneUpView setImage:[NXImage findImageNamed:"Pacs.tiff"]];
	[oneUpView setImageFrame:&pacFrame];
	[oneUpView setMargin:8.0];
	[oneUpView setExtraManBonusTracker:xtraManTracker];
	[[fruitBasket window] setFrameUsingName:"FruitBasket"];
	[[fruitBasket window] setFrameAutosaveName:"FruitBasket"];
	[fruitBasket showLevel:1];
    return self;
}

- layerWindows
{
	// make sure the windows are layered properly
	// Fruit Basket is to be on the bottom, so order it front first.
	if ([[fruitBasket window] delegate] &&
			[[[fruitBasket window] delegate] windowUp])
		[[fruitBasket window] orderFront:self];
	return [super layerWindows];
}

- windowDidMove:sender		// move fruit basket and status with game window 
{	// we completely override super's method, since the window goes to
	// a totally different spot...
    NXRect gameFrame;
	
	[gameWindow getFrame:&gameFrame];
    [[fruitBasket window] moveTo:(NX_X(&gameFrame) - 137)
		:(NX_Y(&gameFrame) - 53)];
    [[levelText window] moveTo:(NX_X(&gameFrame) - 137)
		:NX_Y(&gameFrame)];
	return self;
}


@end
